;
(function($) {
	'use strict';
	var methods = {
		init: function(options) {
			return this.each(function() {
				this.self = $(this);
				methods.destroy.call(this.self);
				this.opt = $.extend(true, {}, $.fn.raty.defaults, options);
				methods._adjustCallback.call(this);
				methods._adjustNumber.call(this);
				methods._adjustHints.call(this);
				this.opt.score = methods._adjustedScore.call(this, this.opt.score);
				if (this.opt.starType !== 'img') {
					methods._adjustStarType.call(this);
				}
				methods._adjustPath.call(this);
				methods._createStars.call(this);
				if (this.opt.cancel) {
					methods._createCancel.call(this);
				}
				if (this.opt.precision) {
					methods._adjustPrecision.call(this);
				}
				methods._createScore.call(this);
				methods._apply.call(this, this.opt.score);
				methods._setTitle.call(this, this.opt.score);
				methods._target.call(this, this.opt.score);
				if (this.opt.readOnly) {
					methods._lock.call(this);
				} else {
					this.style.cursor = 'pointer';
					methods._binds.call(this);
				}
			});
		},
		_adjustCallback: function() {
			var options = ['number', 'readOnly', 'score', 'scoreName', 'target'];
			for (var i = 0; i < options.length; i++) {
				if (typeof this.opt[options[i]] === 'function') {
					this.opt[options[i]] = this.opt[options[i]].call(this);
				}
			}
		},
		_adjustedScore: function(score) {
			if (!score) {
				return score;
			}
			return methods._between(score, 0, this.opt.number);
		},
		_adjustHints: function() {
			if (!this.opt.hints) {
				this.opt.hints = [];
			}
			if (!this.opt.halfShow && !this.opt.half) {
				return;
			}
			var steps = this.opt.precision ? 10 : 2;
			for (var i = 0; i < this.opt.number; i++) {
				var group = this.opt.hints[i];
				if (Object.prototype.toString.call(group) !== '[object Array]') {
					group = [group];
				}
				this.opt.hints[i] = [];
				for (var j = 0; j < steps; j++) {
					var
					hint = group[j],
						last = group[group.length - 1];
					if (last === undefined) {
						last = null;
					}
					this.opt.hints[i][j] = hint === undefined ? last : hint;
				}
			}
		},
		_adjustNumber: function() {
			this.opt.number = methods._between(this.opt.number, 1, this.opt.numberMax);
		},
		_adjustPath: function() {
			this.opt.path = this.opt.path || '';
			if (this.opt.path && this.opt.path.charAt(this.opt.path.length - 1) !== '/') {
				this.opt.path += '/';
			}
		},
		_adjustPrecision: function() {
			this.opt.half = true;
		},
		_adjustStarType: function() {
			var replaces = ['cancelOff', 'cancelOn', 'starHalf', 'starOff', 'starOn'];
			this.opt.path = '';
			for (var i = 0; i < replaces.length; i++) {
				this.opt[replaces[i]] = this.opt[replaces[i]].replace('.', '-');
			}
		},
		_apply: function(score) {
			methods._fill.call(this, score);
			if (score) {
				if (score > 0) {
					this.score.val(score);
				}
				methods._roundStars.call(this, score);
			}
		},
		_between: function(value, min, max) {
			return Math.min(Math.max(parseFloat(value), min), max);
		},
		_binds: function() {
			if (this.cancel) {
				methods._bindOverCancel.call(this);
				methods._bindClickCancel.call(this);
				methods._bindOutCancel.call(this);
			}
			methods._bindOver.call(this);
			methods._bindClick.call(this);
			methods._bindOut.call(this);
		},
		_bindClick: function() {
			var that = this;
			that.stars.on('click.raty', function(evt) {
				var
				execute = true,
					score = (that.opt.half || that.opt.precision) ? that.self.data('score') : (this.alt || $(this).data('alt'));
				if (that.opt.click) {
					execute = that.opt.click.call(that, +score, evt);
				}
				if (execute || execute === undefined) {
					if (that.opt.half && !that.opt.precision) {
						score = methods._roundHalfScore.call(that, score);
					}
					methods._apply.call(that, score);
				}
			});
		},
		_bindClickCancel: function() {
			var that = this;
			that.cancel.on('click.raty', function(evt) {
				that.score.removeAttr('value');
				if (that.opt.click) {
					that.opt.click.call(that, null, evt);
				}
			});
		},
		_bindOut: function() {
			var that = this;
			that.self.on('mouseleave.raty', function(evt) {
				var score = +that.score.val() || undefined;
				methods._apply.call(that, score);
				methods._target.call(that, score, evt);
				methods._resetTitle.call(that);
				if (that.opt.mouseout) {
					that.opt.mouseout.call(that, score, evt);
				}
			});
		},
		_bindOutCancel: function() {
			var that = this;
			that.cancel.on('mouseleave.raty', function(evt) {
				var icon = that.opt.cancelOff;
				if (that.opt.starType !== 'img') {
					icon = that.opt.cancelClass + ' ' + icon;
				}
				methods._setIcon.call(that, this, icon);
				if (that.opt.mouseout) {
					var score = +that.score.val() || undefined;
					that.opt.mouseout.call(that, score, evt);
				}
			});
		},
		_bindOver: function() {
			var that = this,
				action = that.opt.half ? 'mousemove.raty' : 'mouseover.raty';
			that.stars.on(action, function(evt) {
				var score = methods._getScoreByPosition.call(that, evt, this);
				methods._fill.call(that, score);
				if (that.opt.half) {
					methods._roundStars.call(that, score, evt);
					methods._setTitle.call(that, score, evt);
					that.self.data('score', score);
				}
				methods._target.call(that, score, evt);
				if (that.opt.mouseover) {
					that.opt.mouseover.call(that, score, evt);
				}
			});
		},
		_bindOverCancel: function() {
			var that = this;
			that.cancel.on('mouseover.raty', function(evt) {
				var
				starOff = that.opt.path + that.opt.starOff,
					icon = that.opt.cancelOn;
				if (that.opt.starType === 'img') {
					that.stars.attr('src', starOff);
				} else {
					icon = that.opt.cancelClass + ' ' + icon;
					that.stars.attr('class', starOff);
				}
				methods._setIcon.call(that, this, icon);
				methods._target.call(that, null, evt);
				if (that.opt.mouseover) {
					that.opt.mouseover.call(that, null);
				}
			});
		},
		_buildScoreField: function() {
			return $('<input />', {
				name: this.opt.scoreName,
				type: 'hidden'
			}).appendTo(this);
		},
		_createCancel: function() {
			var icon = this.opt.path + this.opt.cancelOff,
				cancel = $('<' + this.opt.starType + ' />', {
					title: this.opt.cancelHint,
					'class': this.opt.cancelClass
				});
			if (this.opt.starType === 'img') {
				cancel.attr({
					src: icon,
					alt: 'x'
				});
			} else {
				cancel.attr('data-alt', 'x').addClass(icon);
			}
			if (this.opt.cancelPlace === 'left') {
				this.self.prepend('&#160;').prepend(cancel);
			} else {
				this.self.append('&#160;').append(cancel);
			}
			this.cancel = cancel;
		},
		_createScore: function() {
			var score = $(this.opt.targetScore);
			this.score = score.length ? score : methods._buildScoreField.call(this);
		},
		_createStars: function() {
			for (var i = 1; i <= this.opt.number; i++) {
				var
				name = methods._nameForIndex.call(this, i),
					attrs = {
						alt: i,
						src: this.opt.path + this.opt[name]
					};
				if (this.opt.starType !== 'img') {
					attrs = {
						'data-alt': i,
						'class': attrs.src
					};
				}
				attrs.title = methods._getHint.call(this, i);
				$('<' + this.opt.starType + ' />', attrs).appendTo(this);
				if (this.opt.space) {
					this.self.append(i < this.opt.number ? '&#160;' : '');
				}
			}
			this.stars = this.self.children(this.opt.starType);
		},
		_error: function(message) {
			$(this).text(message);
			$.error(message);
		},
		_fill: function(score) {
			var hash = 0;
			for (var i = 1; i <= this.stars.length; i++) {
				var
				icon, star = this.stars[i - 1],
					turnOn = methods._turnOn.call(this, i, score);
				if (this.opt.iconRange && this.opt.iconRange.length > hash) {
					var irange = this.opt.iconRange[hash];
					icon = methods._getRangeIcon.call(this, irange, turnOn);
					if (i <= irange.range) {
						methods._setIcon.call(this, star, icon);
					}
					if (i === irange.range) {
						hash++;
					}
				} else {
					icon = this.opt[turnOn ? 'starOn' : 'starOff'];
					methods._setIcon.call(this, star, icon);
				}
			}
		},
		_getFirstDecimal: function(number) {
			var
			decimal = number.toString().split('.')[1],
				result = 0;
			if (decimal) {
				result = parseInt(decimal.charAt(0), 10);
				if (decimal.slice(1, 5) === '9999') {
					result++;
				}
			}
			return result;
		},
		_getRangeIcon: function(irange, turnOn) {
			return turnOn ? irange.on || this.opt.starOn : irange.off || this.opt.starOff;
		},
		_getScoreByPosition: function(evt, icon) {
			var score = parseInt(icon.alt || icon.getAttribute('data-alt'), 10);
			if (this.opt.half) {
				var
				size = methods._getWidth.call(this),
					percent = parseFloat((evt.pageX - $(icon).offset().left) / size);
				score = score - 1 + percent;
			}
			return score;
		},
		_getHint: function(score, evt) {
			if (score !== 0 && !score) {
				return this.opt.noRatedMsg;
			}
			var
			decimal = methods._getFirstDecimal.call(this, score),
				integer = Math.ceil(score),
				group = this.opt.hints[(integer || 1) - 1],
				hint = group,
				set = !evt || this.move;
			if (this.opt.precision) {
				if (set) {
					decimal = decimal === 0 ? 9 : decimal - 1;
				}
				hint = group[decimal];
			} else if (this.opt.halfShow || this.opt.half) {
				decimal = set && decimal === 0 ? 1 : decimal > 5 ? 1 : 0;
				hint = group[decimal];
			}
			return hint === '' ? '' : hint || score;
		},
		_getWidth: function() {
			var width = this.stars[0].width || parseFloat(this.stars.eq(0).css('font-size'));
			if (!width) {
				methods._error.call(this, 'Could not get the icon width!');
			}
			return width;
		},
		_lock: function() {
			var hint = methods._getHint.call(this, this.score.val());
			this.style.cursor = '';
			this.title = hint;
			this.score.prop('readonly', true);
			this.stars.prop('title', hint);
			if (this.cancel) {
				this.cancel.hide();
			}
			this.self.data('readonly', true);
		},
		_nameForIndex: function(i) {
			return this.opt.score && this.opt.score >= i ? 'starOn' : 'starOff';
		},
		_resetTitle: function(star) {
			for (var i = 0; i < this.opt.number; i++) {
				this.stars[i].title = methods._getHint.call(this, i + 1);
			}
		},
		_roundHalfScore: function(score) {
			var integer = parseInt(score, 10),
				decimal = methods._getFirstDecimal.call(this, score);
			if (decimal !== 0) {
				decimal = decimal > 5 ? 1 : 0.5;
			}
			return integer + decimal;
		},
		_roundStars: function(score, evt) {
			var
			decimal = (score % 1).toFixed(2),
				name;
			if (evt || this.move) {
				name = decimal > 0.5 ? 'starOn' : 'starHalf';
			} else if (decimal > this.opt.round.down) {
				name = 'starOn';
				if (this.opt.halfShow && decimal < this.opt.round.up) {
					name = 'starHalf';
				} else if (decimal < this.opt.round.full) {
					name = 'starOff';
				}
			}
			if (name) {
				var
				icon = this.opt[name],
					star = this.stars[Math.ceil(score) - 1];
				methods._setIcon.call(this, star, icon);
			}
		},
		_setIcon: function(star, icon) {
			star[this.opt.starType === 'img' ? 'src' : 'className'] = this.opt.path + icon;
		},
		_setTarget: function(target, score) {
			if (score) {
				score = this.opt.targetFormat.toString().replace('{score}', score);
			}
			if (target.is(':input')) {
				target.val(score);
			} else {
				target.html(score);
			}
		},
		_setTitle: function(score, evt) {
			if (score) {
				var
				integer = parseInt(Math.ceil(score), 10),
					star = this.stars[integer - 1];
				star.title = methods._getHint.call(this, score, evt);
			}
		},
		_target: function(score, evt) {
			if (this.opt.target) {
				var target = $(this.opt.target);
				if (!target.length) {
					methods._error.call(this, 'Target selector invalid or missing!');
				}
				var mouseover = evt && evt.type === 'mouseover';
				if (score === undefined) {
					score = this.opt.targetText;
				} else if (score === null) {
					score = mouseover ? this.opt.cancelHint : this.opt.targetText;
				} else {
					if (this.opt.targetType === 'hint') {
						score = methods._getHint.call(this, score, evt);
					} else if (this.opt.precision) {
						score = parseFloat(score).toFixed(1);
					}
					var mousemove = evt && evt.type === 'mousemove';
					if (!mouseover && !mousemove && !this.opt.targetKeep) {
						score = this.opt.targetText;
					}
				}
				methods._setTarget.call(this, target, score);
			}
		},
		_turnOn: function(i, score) {
			return this.opt.single ? (i === score) : (i <= score);
		},
		_unlock: function() {
			this.style.cursor = 'pointer';
			this.removeAttribute('title');
			this.score.removeAttr('readonly');
			this.self.data('readonly', false);
			for (var i = 0; i < this.opt.number; i++) {
				this.stars[i].title = methods._getHint.call(this, i + 1);
			}
			if (this.cancel) {
				this.cancel.css('display', '');
			}
		},
		cancel: function(click) {
			return this.each(function() {
				var self = $(this);
				if (self.data('readonly') !== true) {
					methods[click ? 'click' : 'score'].call(self, null);
					this.score.removeAttr('value');
				}
			});
		},
		click: function(score) {
			return this.each(function() {
				if ($(this).data('readonly') !== true) {
					score = methods._adjustedScore.call(this, score);
					methods._apply.call(this, score);
					if (this.opt.click) {
						this.opt.click.call(this, score, $.Event('click'));
					}
					methods._target.call(this, score);
				}
			});
		},
		destroy: function() {
			return this.each(function() {
				var self = $(this),
					raw = self.data('raw');
				if (raw) {
					self.off('.raty').empty().css({
						cursor: raw.style.cursor
					}).removeData('readonly');
				} else {
					self.data('raw', self.clone()[0]);
				}
			});
		},
		getScore: function() {
			var score = [],
				value;
			this.each(function() {
				value = this.score.val();
				score.push(value ? +value : undefined);
			});
			return (score.length > 1) ? score : score[0];
		},
		move: function(score) {
			return this.each(function() {
				var
				integer = parseInt(score, 10),
					decimal = methods._getFirstDecimal.call(this, score);
				if (integer >= this.opt.number) {
					integer = this.opt.number - 1;
					decimal = 10;
				}
				var
				width = methods._getWidth.call(this),
					steps = width / 10,
					star = $(this.stars[integer]),
					percent = star.offset().left + steps * decimal,
					evt = $.Event('mousemove', {
						pageX: percent
					});
				this.move = true;
				star.trigger(evt);
				this.move = false;
			});
		},
		readOnly: function(readonly) {
			return this.each(function() {
				var self = $(this);
				if (self.data('readonly') !== readonly) {
					if (readonly) {
						self.off('.raty').children('img').off('.raty');
						methods._lock.call(this);
					} else {
						methods._binds.call(this);
						methods._unlock.call(this);
					}
					self.data('readonly', readonly);
				}
			});
		},
		reload: function() {
			return methods.set.call(this, {});
		},
		score: function() {
			var self = $(this);
			return arguments.length ? methods.setScore.apply(self, arguments) : methods.getScore.call(self);
		},
		set: function(options) {
			return this.each(function() {
				$(this).raty($.extend({}, this.opt, options));
			});
		},
		setScore: function(score) {
			return this.each(function() {
				if ($(this).data('readonly') !== true) {
					score = methods._adjustedScore.call(this, score);
					methods._apply.call(this, score);
					methods._target.call(this, score);
				}
			});
		}
	};
	$.fn.raty = function(method) {
		if (methods[method]) {
			return methods[method].apply(this, Array.prototype.slice.call(arguments, 1));
		} else if (typeof method === 'object' || !method) {
			return methods.init.apply(this, arguments);
		} else {
			$.error('Method ' + method + ' does not exist!');
		}
	};
	$.fn.raty.defaults = {
		cancel: false,
		cancelClass: 'raty-cancel',
		cancelHint: 'Cancel this rating!',
		cancelOff: 'cancel-off.png',
		cancelOn: 'cancel-on.png',
		cancelPlace: 'left',
		click: undefined,
		half: false,
		halfShow: true,
		hints: ['bad', 'poor', 'regular', 'good', 'gorgeous'],
		iconRange: undefined,
		mouseout: undefined,
		mouseover: undefined,
		noRatedMsg: 'Not rated yet!',
		number: 5,
		numberMax: 20,
		path: undefined,
		precision: false,
		readOnly: false,
		round: {
			down: 0.25,
			full: 0.6,
			up: 0.76
		},
		score: undefined,
		scoreName: 'score',
		single: false,
		space: true,
		starHalf: 'star-half.png',
		starOff: 'star-off.png',
		starOn: 'star-on.png',
		starType: 'img',
		target: undefined,
		targetFormat: '{score}',
		targetKeep: false,
		targetScore: undefined,
		targetText: '',
		targetType: 'hint'
	};
})(jQuery);;
(function($) {
	$.flexslider = function(el, options) {
		var slider = $(el);
		slider.vars = $.extend({}, $.flexslider.defaults, options);
		var namespace = slider.vars.namespace,
			msGesture = window.navigator && window.navigator.msPointerEnabled && window.MSGesture,
			touch = (("ontouchstart" in window) || msGesture || window.DocumentTouch && document instanceof DocumentTouch) && slider.vars.touch,
			eventType = "click touchend MSPointerUp keyup",
			watchedEvent = "",
			watchedEventClearTimer, vertical = slider.vars.direction === "vertical",
			reverse = slider.vars.reverse,
			carousel = (slider.vars.itemWidth > 0),
			fade = slider.vars.animation === "fade",
			asNav = slider.vars.asNavFor !== "",
			methods = {},
			focused = true;
		$.data(el, "flexslider", slider);
		methods = {
			init: function() {
				slider.animating = false;
				slider.currentSlide = parseInt((slider.vars.startAt ? slider.vars.startAt : 0), 10);
				if (isNaN(slider.currentSlide)) {
					slider.currentSlide = 0;
				}
				slider.animatingTo = slider.currentSlide;
				slider.atEnd = (slider.currentSlide === 0 || slider.currentSlide === slider.last);
				slider.containerSelector = slider.vars.selector.substr(0, slider.vars.selector.search(' '));
				slider.slides = $(slider.vars.selector, slider);
				slider.container = $(slider.containerSelector, slider);
				slider.count = slider.slides.length;
				slider.syncExists = $(slider.vars.sync).length > 0;
				if (slider.vars.animation === "slide") {
					slider.vars.animation = "swing";
				}
				slider.prop = (vertical) ? "top" : "marginLeft";
				slider.args = {};
				slider.manualPause = false;
				slider.stopped = false;
				slider.started = false;
				slider.startTimeout = null;
				slider.transitions = !slider.vars.video && !fade && slider.vars.useCSS && (function() {
					var obj = document.createElement('div'),
						props = ['perspectiveProperty', 'WebkitPerspective', 'MozPerspective', 'OPerspective', 'msPerspective'];
					for (var i in props) {
						if (obj.style[props[i]] !== undefined) {
							slider.pfx = props[i].replace('Perspective', '').toLowerCase();
							slider.prop = "-" + slider.pfx + "-transform";
							return true;
						}
					}
					return false;
				}());
				slider.ensureAnimationEnd = '';
				if (slider.vars.controlsContainer !== "") slider.controlsContainer = $(slider.vars.controlsContainer).length > 0 && $(slider.vars.controlsContainer);
				if (slider.vars.manualControls !== "") slider.manualControls = $(slider.vars.manualControls).length > 0 && $(slider.vars.manualControls);
				if (slider.vars.customDirectionNav !== "") slider.customDirectionNav = $(slider.vars.customDirectionNav).length === 2 && $(slider.vars.customDirectionNav);
				if (slider.vars.randomize) {
					slider.slides.sort(function() {
						return (Math.round(Math.random()) - 0.5);
					});
					slider.container.empty().append(slider.slides);
				}
				slider.doMath();
				slider.setup("init");
				if (slider.vars.controlNav) {
					methods.controlNav.setup();
				}
				if (slider.vars.directionNav) {
					methods.directionNav.setup();
				}
				if (slider.vars.keyboard && ($(slider.containerSelector).length === 1 || slider.vars.multipleKeyboard)) {
					$(document).bind('keyup', function(event) {
						var keycode = event.keyCode;
						if (!slider.animating && (keycode === 39 || keycode === 37)) {
							var target = (keycode === 39) ? slider.getTarget('next') : (keycode === 37) ? slider.getTarget('prev') : false;
							slider.flexAnimate(target, slider.vars.pauseOnAction);
						}
					});
				}
				if (slider.vars.mousewheel) {
					slider.bind('mousewheel', function(event, delta, deltaX, deltaY) {
						event.preventDefault();
						var target = (delta < 0) ? slider.getTarget('next') : slider.getTarget('prev');
						slider.flexAnimate(target, slider.vars.pauseOnAction);
					});
				}
				if (slider.vars.pausePlay) {
					methods.pausePlay.setup();
				}
				if (slider.vars.slideshow && slider.vars.pauseInvisible) {
					methods.pauseInvisible.init();
				}
				if (slider.vars.slideshow) {
					if (slider.vars.pauseOnHover) {
						slider.hover(function() {
							if (!slider.manualPlay && !slider.manualPause) {
								slider.pause();
							}
						}, function() {
							if (!slider.manualPause && !slider.manualPlay && !slider.stopped) {
								slider.play();
							}
						});
					}
					if (!slider.vars.pauseInvisible || !methods.pauseInvisible.isHidden()) {
						(slider.vars.initDelay > 0) ? slider.startTimeout = setTimeout(slider.play, slider.vars.initDelay) : slider.play();
					}
				}
				if (asNav) {
					methods.asNav.setup();
				}
				if (touch && slider.vars.touch) {
					methods.touch();
				}
				if (!fade || (fade && slider.vars.smoothHeight)) {
					$(window).bind("resize orientationchange focus", methods.resize);
				}
				slider.find("img").attr("draggable", "false");
				setTimeout(function() {
					slider.vars.start(slider);
				}, 200);
			},
			asNav: {
				setup: function() {
					slider.asNav = true;
					slider.animatingTo = Math.floor(slider.currentSlide / slider.move);
					slider.currentItem = slider.currentSlide;
					slider.slides.removeClass(namespace + "active-slide").eq(slider.currentItem).addClass(namespace + "active-slide");
					if (!msGesture) {
						slider.slides.on(eventType, function(e) {
							e.preventDefault();
							var $slide = $(this),
								target = $slide.index();
							var posFromLeft = $slide.offset().left - $(slider).scrollLeft();
							if (posFromLeft <= 0 && $slide.hasClass(namespace + 'active-slide')) {
								slider.flexAnimate(slider.getTarget("prev"), true);
							} else if (!$(slider.vars.asNavFor).data('flexslider').animating && !$slide.hasClass(namespace + "active-slide")) {
								slider.direction = (slider.currentItem < target) ? "next" : "prev";
								slider.flexAnimate(target, slider.vars.pauseOnAction, false, true, true);
							}
						});
					} else {
						el._slider = slider;
						slider.slides.each(function() {
							var that = this;
							that._gesture = new MSGesture();
							that._gesture.target = that;
							that.addEventListener("MSPointerDown", function(e) {
								e.preventDefault();
								if (e.currentTarget._gesture) {
									e.currentTarget._gesture.addPointer(e.pointerId);
								}
							}, false);
							that.addEventListener("MSGestureTap", function(e) {
								e.preventDefault();
								var $slide = $(this),
									target = $slide.index();
								if (!$(slider.vars.asNavFor).data('flexslider').animating && !$slide.hasClass('active')) {
									slider.direction = (slider.currentItem < target) ? "next" : "prev";
									slider.flexAnimate(target, slider.vars.pauseOnAction, false, true, true);
								}
							});
						});
					}
				}
			},
			controlNav: {
				setup: function() {
					if (!slider.manualControls) {
						methods.controlNav.setupPaging();
					} else {
						methods.controlNav.setupManual();
					}
				},
				setupPaging: function() {
					var type = (slider.vars.controlNav === "thumbnails") ? 'control-thumbs' : 'control-paging',
						j = 1,
						item, slide;
					slider.controlNavScaffold = $('<ol class="' + namespace + 'control-nav ' + namespace + type + '"></ol>');
					if (slider.pagingCount > 1) {
						for (var i = 0; i < slider.pagingCount; i++) {
							slide = slider.slides.eq(i);
							item = (slider.vars.controlNav === "thumbnails") ? '<img src="' + slide.attr('data-thumb') + '"/>' : '<a>' + j + '</a>';
							if ('thumbnails' === slider.vars.controlNav && true === slider.vars.thumbCaptions) {
								var captn = slide.attr('data-thumbcaption');
								if ('' !== captn && undefined !== captn) {
									item += '<span class="' + namespace + 'caption">' + captn + '</span>';
								}
							}
							slider.controlNavScaffold.append('<li>' + item + '</li>');
							j++;
						}
					}(slider.controlsContainer) ? $(slider.controlsContainer).append(slider.controlNavScaffold) : slider.append(slider.controlNavScaffold);
					methods.controlNav.set();
					methods.controlNav.active();
					slider.controlNavScaffold.delegate('a, img', eventType, function(event) {
						event.preventDefault();
						if (watchedEvent === "" || watchedEvent === event.type) {
							var $this = $(this),
								target = slider.controlNav.index($this);
							if (!$this.hasClass(namespace + 'active')) {
								slider.direction = (target > slider.currentSlide) ? "next" : "prev";
								slider.flexAnimate(target, slider.vars.pauseOnAction);
							}
						}
						if (watchedEvent === "") {
							watchedEvent = event.type;
						}
						methods.setToClearWatchedEvent();
					});
				},
				setupManual: function() {
					slider.controlNav = slider.manualControls;
					methods.controlNav.active();
					slider.controlNav.bind(eventType, function(event) {
						event.preventDefault();
						if (watchedEvent === "" || watchedEvent === event.type) {
							var $this = $(this),
								target = slider.controlNav.index($this);
							if (!$this.hasClass(namespace + 'active')) {
								(target > slider.currentSlide) ? slider.direction = "next" : slider.direction = "prev";
								slider.flexAnimate(target, slider.vars.pauseOnAction);
							}
						}
						if (watchedEvent === "") {
							watchedEvent = event.type;
						}
						methods.setToClearWatchedEvent();
					});
				},
				set: function() {
					var selector = (slider.vars.controlNav === "thumbnails") ? 'img' : 'a';
					slider.controlNav = $('.' + namespace + 'control-nav li ' + selector, (slider.controlsContainer) ? slider.controlsContainer : slider);
				},
				active: function() {
					slider.controlNav.removeClass(namespace + "active").eq(slider.animatingTo).addClass(namespace + "active");
				},
				update: function(action, pos) {
					if (slider.pagingCount > 1 && action === "add") {
						slider.controlNavScaffold.append($('<li><a>' + slider.count + '</a></li>'));
					} else if (slider.pagingCount === 1) {
						slider.controlNavScaffold.find('li').remove();
					} else {
						slider.controlNav.eq(pos).closest('li').remove();
					}
					methods.controlNav.set();
					(slider.pagingCount > 1 && slider.pagingCount !== slider.controlNav.length) ? slider.update(pos, action) : methods.controlNav.active();
				}
			},
			directionNav: {
				setup: function() {
					var directionNavScaffold = $('<ul class="' + namespace + 'direction-nav"><li class="' + namespace + 'nav-prev"><a class="' + namespace + 'prev" href="#">' + slider.vars.prevText + '</a></li><li class="' + namespace + 'nav-next"><a class="' + namespace + 'next" href="#">' + slider.vars.nextText + '</a></li></ul>');
					if (slider.customDirectionNav) {
						slider.directionNav = slider.customDirectionNav;
					} else if (slider.controlsContainer) {
						$(slider.controlsContainer).append(directionNavScaffold);
						slider.directionNav = $('.' + namespace + 'direction-nav li a', slider.controlsContainer);
					} else {
						slider.append(directionNavScaffold);
						slider.directionNav = $('.' + namespace + 'direction-nav li a', slider);
					}
					methods.directionNav.update();
					slider.directionNav.bind(eventType, function(event) {
						event.preventDefault();
						var target;
						if (watchedEvent === "" || watchedEvent === event.type) {
							target = ($(this).hasClass(namespace + 'next')) ? slider.getTarget('next') : slider.getTarget('prev');
							slider.flexAnimate(target, slider.vars.pauseOnAction);
						}
						if (watchedEvent === "") {
							watchedEvent = event.type;
						}
						methods.setToClearWatchedEvent();
					});
				},
				update: function() {
					var disabledClass = namespace + 'disabled';
					if (slider.pagingCount === 1) {
						slider.directionNav.addClass(disabledClass).attr('tabindex', '-1');
					} else if (!slider.vars.animationLoop) {
						if (slider.animatingTo === 0) {
							slider.directionNav.removeClass(disabledClass).filter('.' + namespace + "prev").addClass(disabledClass).attr('tabindex', '-1');
						} else if (slider.animatingTo === slider.last) {
							slider.directionNav.removeClass(disabledClass).filter('.' + namespace + "next").addClass(disabledClass).attr('tabindex', '-1');
						} else {
							slider.directionNav.removeClass(disabledClass).removeAttr('tabindex');
						}
					} else {
						slider.directionNav.removeClass(disabledClass).removeAttr('tabindex');
					}
				}
			},
			pausePlay: {
				setup: function() {
					var pausePlayScaffold = $('<div class="' + namespace + 'pauseplay"><a></a></div>');
					if (slider.controlsContainer) {
						slider.controlsContainer.append(pausePlayScaffold);
						slider.pausePlay = $('.' + namespace + 'pauseplay a', slider.controlsContainer);
					} else {
						slider.append(pausePlayScaffold);
						slider.pausePlay = $('.' + namespace + 'pauseplay a', slider);
					}
					methods.pausePlay.update((slider.vars.slideshow) ? namespace + 'pause' : namespace + 'play');
					slider.pausePlay.bind(eventType, function(event) {
						event.preventDefault();
						if (watchedEvent === "" || watchedEvent === event.type) {
							if ($(this).hasClass(namespace + 'pause')) {
								slider.manualPause = true;
								slider.manualPlay = false;
								slider.pause();
							} else {
								slider.manualPause = false;
								slider.manualPlay = true;
								slider.play();
							}
						}
						if (watchedEvent === "") {
							watchedEvent = event.type;
						}
						methods.setToClearWatchedEvent();
					});
				},
				update: function(state) {
					(state === "play") ? slider.pausePlay.removeClass(namespace + 'pause').addClass(namespace + 'play').html(slider.vars.playText) : slider.pausePlay.removeClass(namespace + 'play').addClass(namespace + 'pause').html(slider.vars.pauseText);
				}
			},
			touch: function() {
				var startX, startY, offset, cwidth, dx, startT, onTouchStart, onTouchMove, onTouchEnd, scrolling = false,
					localX = 0,
					localY = 0,
					accDx = 0;
				if (!msGesture) {
					onTouchStart = function(e) {
						if (slider.animating) {
							e.preventDefault();
						} else if ((window.navigator.msPointerEnabled) || e.touches.length === 1) {
							slider.pause();
							cwidth = (vertical) ? slider.h : slider.w;
							startT = Number(new Date());
							localX = e.touches[0].pageX;
							localY = e.touches[0].pageY;
							offset = (carousel && reverse && slider.animatingTo === slider.last) ? 0 : (carousel && reverse) ? slider.limit - (((slider.itemW + slider.vars.itemMargin) * slider.move) * slider.animatingTo) : (carousel && slider.currentSlide === slider.last) ? slider.limit : (carousel) ? ((slider.itemW + slider.vars.itemMargin) * slider.move) * slider.currentSlide : (reverse) ? (slider.last - slider.currentSlide + slider.cloneOffset) * cwidth : (slider.currentSlide + slider.cloneOffset) * cwidth;
							startX = (vertical) ? localY : localX;
							startY = (vertical) ? localX : localY;
							el.addEventListener('touchmove', onTouchMove, false);
							el.addEventListener('touchend', onTouchEnd, false);
						}
					};
					onTouchMove = function(e) {
						localX = e.touches[0].pageX;
						localY = e.touches[0].pageY;
						dx = (vertical) ? startX - localY : startX - localX;
						scrolling = (vertical) ? (Math.abs(dx) < Math.abs(localX - startY)) : (Math.abs(dx) < Math.abs(localY - startY));
						var fxms = 500;
						if (!scrolling || Number(new Date()) - startT > fxms) {
							e.preventDefault();
							if (!fade && slider.transitions) {
								if (!slider.vars.animationLoop) {
									dx = dx / ((slider.currentSlide === 0 && dx < 0 || slider.currentSlide === slider.last && dx > 0) ? (Math.abs(dx) / cwidth + 2) : 1);
								}
								slider.setProps(offset + dx, "setTouch");
							}
						}
					};
					onTouchEnd = function(e) {
						el.removeEventListener('touchmove', onTouchMove, false);
						if (slider.animatingTo === slider.currentSlide && !scrolling && !(dx === null)) {
							var updateDx = (reverse) ? -dx : dx,
								target = (updateDx > 0) ? slider.getTarget('next') : slider.getTarget('prev');
							if (slider.canAdvance(target) && (Number(new Date()) - startT < 550 && Math.abs(updateDx) > 50 || Math.abs(updateDx) > cwidth / 2)) {
								slider.flexAnimate(target, slider.vars.pauseOnAction);
							} else {
								if (!fade) {
									slider.flexAnimate(slider.currentSlide, slider.vars.pauseOnAction, true);
								}
							}
						}
						el.removeEventListener('touchend', onTouchEnd, false);
						startX = null;
						startY = null;
						dx = null;
						offset = null;
					};
					el.addEventListener('touchstart', onTouchStart, false);
				} else {
					el.style.msTouchAction = "none";
					el._gesture = new MSGesture();
					el._gesture.target = el;
					el.addEventListener("MSPointerDown", onMSPointerDown, false);
					el._slider = slider;
					el.addEventListener("MSGestureChange", onMSGestureChange, false);
					el.addEventListener("MSGestureEnd", onMSGestureEnd, false);

					function onMSPointerDown(e) {
						e.stopPropagation();
						if (slider.animating) {
							e.preventDefault();
						} else {
							slider.pause();
							el._gesture.addPointer(e.pointerId);
							accDx = 0;
							cwidth = (vertical) ? slider.h : slider.w;
							startT = Number(new Date());
							offset = (carousel && reverse && slider.animatingTo === slider.last) ? 0 : (carousel && reverse) ? slider.limit - (((slider.itemW + slider.vars.itemMargin) * slider.move) * slider.animatingTo) : (carousel && slider.currentSlide === slider.last) ? slider.limit : (carousel) ? ((slider.itemW + slider.vars.itemMargin) * slider.move) * slider.currentSlide : (reverse) ? (slider.last - slider.currentSlide + slider.cloneOffset) * cwidth : (slider.currentSlide + slider.cloneOffset) * cwidth;
						}
					}
					function onMSGestureChange(e) {
						e.stopPropagation();
						var slider = e.target._slider;
						if (!slider) {
							return;
						}
						var transX = -e.translationX,
							transY = -e.translationY;
						accDx = accDx + ((vertical) ? transY : transX);
						dx = accDx;
						scrolling = (vertical) ? (Math.abs(accDx) < Math.abs(-transX)) : (Math.abs(accDx) < Math.abs(-transY));
						if (e.detail === e.MSGESTURE_FLAG_INERTIA) {
							setImmediate(function() {
								el._gesture.stop();
							});
							return;
						}
						if (!scrolling || Number(new Date()) - startT > 500) {
							e.preventDefault();
							if (!fade && slider.transitions) {
								if (!slider.vars.animationLoop) {
									dx = accDx / ((slider.currentSlide === 0 && accDx < 0 || slider.currentSlide === slider.last && accDx > 0) ? (Math.abs(accDx) / cwidth + 2) : 1);
								}
								slider.setProps(offset + dx, "setTouch");
							}
						}
					}
					function onMSGestureEnd(e) {
						e.stopPropagation();
						var slider = e.target._slider;
						if (!slider) {
							return;
						}
						if (slider.animatingTo === slider.currentSlide && !scrolling && !(dx === null)) {
							var updateDx = (reverse) ? -dx : dx,
								target = (updateDx > 0) ? slider.getTarget('next') : slider.getTarget('prev');
							if (slider.canAdvance(target) && (Number(new Date()) - startT < 550 && Math.abs(updateDx) > 50 || Math.abs(updateDx) > cwidth / 2)) {
								slider.flexAnimate(target, slider.vars.pauseOnAction);
							} else {
								if (!fade) {
									slider.flexAnimate(slider.currentSlide, slider.vars.pauseOnAction, true);
								}
							}
						}
						startX = null;
						startY = null;
						dx = null;
						offset = null;
						accDx = 0;
					}
				}
			},
			resize: function() {
				if (!slider.animating && slider.is(':visible')) {
					if (!carousel) {
						slider.doMath();
					}
					if (fade) {
						methods.smoothHeight();
					} else if (carousel) {
						slider.slides.width(slider.computedW);
						slider.update(slider.pagingCount);
						slider.setProps();
					} else if (vertical) {
						slider.viewport.height(slider.h);
						slider.setProps(slider.h, "setTotal");
					} else {
						if (slider.vars.smoothHeight) {
							methods.smoothHeight();
						}
						slider.newSlides.width(slider.computedW);
						slider.setProps(slider.computedW, "setTotal");
					}
				}
			},
			smoothHeight: function(dur) {
				if (!vertical || fade) {
					var $obj = (fade) ? slider : slider.viewport;
					(dur) ? $obj.animate({
						"height": slider.slides.eq(slider.animatingTo).height()
					}, dur) : $obj.height(slider.slides.eq(slider.animatingTo).height());
				}
			},
			sync: function(action) {
				var $obj = $(slider.vars.sync).data("flexslider"),
					target = slider.animatingTo;
				switch (action) {
				case "animate":
					$obj.flexAnimate(target, slider.vars.pauseOnAction, false, true);
					break;
				case "play":
					if (!$obj.playing && !$obj.asNav) {
						$obj.play();
					}
					break;
				case "pause":
					$obj.pause();
					break;
				}
			},
			uniqueID: function($clone) {
				$clone.filter('[id]').add($clone.find('[id]')).each(function() {
					var $this = $(this);
					$this.attr('id', $this.attr('id') + '_clone');
				});
				return $clone;
			},
			pauseInvisible: {
				visProp: null,
				init: function() {
					var visProp = methods.pauseInvisible.getHiddenProp();
					if (visProp) {
						var evtname = visProp.replace(/[H|h]idden/, '') + 'visibilitychange';
						document.addEventListener(evtname, function() {
							if (methods.pauseInvisible.isHidden()) {
								if (slider.startTimeout) {
									clearTimeout(slider.startTimeout);
								} else {
									slider.pause();
								}
							} else {
								if (slider.started) {
									slider.play();
								} else {
									if (slider.vars.initDelay > 0) {
										setTimeout(slider.play, slider.vars.initDelay);
									} else {
										slider.play();
									}
								}
							}
						});
					}
				},
				isHidden: function() {
					var prop = methods.pauseInvisible.getHiddenProp();
					if (!prop) {
						return false;
					}
					return document[prop];
				},
				getHiddenProp: function() {
					var prefixes = ['webkit', 'moz', 'ms', 'o'];
					if ('hidden' in document) {
						return 'hidden';
					}
					for (var i = 0; i < prefixes.length; i++) {
						if ((prefixes[i] + 'Hidden') in document) {
							return prefixes[i] + 'Hidden';
						}
					}
					return null;
				}
			},
			setToClearWatchedEvent: function() {
				clearTimeout(watchedEventClearTimer);
				watchedEventClearTimer = setTimeout(function() {
					watchedEvent = "";
				}, 3000);
			}
		};
		slider.flexAnimate = function(target, pause, override, withSync, fromNav) {
			if (!slider.vars.animationLoop && target !== slider.currentSlide) {
				slider.direction = (target > slider.currentSlide) ? "next" : "prev";
			}
			if (asNav && slider.pagingCount === 1) slider.direction = (slider.currentItem < target) ? "next" : "prev";
			if (!slider.animating && (slider.canAdvance(target, fromNav) || override) && slider.is(":visible")) {
				if (asNav && withSync) {
					var master = $(slider.vars.asNavFor).data('flexslider');
					slider.atEnd = target === 0 || target === slider.count - 1;
					master.flexAnimate(target, true, false, true, fromNav);
					slider.direction = (slider.currentItem < target) ? "next" : "prev";
					master.direction = slider.direction;
					if (Math.ceil((target + 1) / slider.visible) - 1 !== slider.currentSlide && target !== 0) {
						slider.currentItem = target;
						slider.slides.removeClass(namespace + "active-slide").eq(target).addClass(namespace + "active-slide");
						target = Math.floor(target / slider.visible);
					} else {
						slider.currentItem = target;
						slider.slides.removeClass(namespace + "active-slide").eq(target).addClass(namespace + "active-slide");
						return false;
					}
				}
				slider.animating = true;
				slider.animatingTo = target;
				if (pause) {
					slider.pause();
				}
				slider.vars.before(slider);
				if (slider.syncExists && !fromNav) {
					methods.sync("animate");
				}
				if (slider.vars.controlNav) {
					methods.controlNav.active();
				}
				if (!carousel) {
					slider.slides.removeClass(namespace + 'active-slide').eq(target).addClass(namespace + 'active-slide');
				}
				slider.atEnd = target === 0 || target === slider.last;
				if (slider.vars.directionNav) {
					methods.directionNav.update();
				}
				if (target === slider.last) {
					slider.vars.end(slider);
					if (!slider.vars.animationLoop) {
						slider.pause();
					}
				}
				if (!fade) {
					var dimension = (vertical) ? slider.slides.filter(':first').height() : slider.computedW,
						margin, slideString, calcNext;
					if (carousel) {
						margin = slider.vars.itemMargin;
						calcNext = ((slider.itemW + margin) * slider.move) * slider.animatingTo;
						slideString = (calcNext > slider.limit && slider.visible !== 1) ? slider.limit : calcNext;
					} else if (slider.currentSlide === 0 && target === slider.count - 1 && slider.vars.animationLoop && slider.direction !== "next") {
						slideString = (reverse) ? (slider.count + slider.cloneOffset) * dimension : 0;
					} else if (slider.currentSlide === slider.last && target === 0 && slider.vars.animationLoop && slider.direction !== "prev") {
						slideString = (reverse) ? 0 : (slider.count + 1) * dimension;
					} else {
						slideString = (reverse) ? ((slider.count - 1) - target + slider.cloneOffset) * dimension : (target + slider.cloneOffset) * dimension;
					}
					slider.setProps(slideString, "", slider.vars.animationSpeed);
					if (slider.transitions) {
						if (!slider.vars.animationLoop || !slider.atEnd) {
							slider.animating = false;
							slider.currentSlide = slider.animatingTo;
						}
						slider.container.unbind("webkitTransitionEnd transitionend");
						slider.container.bind("webkitTransitionEnd transitionend", function() {
							clearTimeout(slider.ensureAnimationEnd);
							slider.wrapup(dimension);
						});
						clearTimeout(slider.ensureAnimationEnd);
						slider.ensureAnimationEnd = setTimeout(function() {
							slider.wrapup(dimension);
						}, slider.vars.animationSpeed + 100);
					} else {
						slider.container.animate(slider.args, slider.vars.animationSpeed, slider.vars.easing, function() {
							slider.wrapup(dimension);
						});
					}
				} else {
					if (!touch) {
						slider.slides.eq(slider.currentSlide).css({
							"zIndex": 1
						}).animate({
							"opacity": 0
						}, slider.vars.animationSpeed, slider.vars.easing);
						slider.slides.eq(target).css({
							"zIndex": 2
						}).animate({
							"opacity": 1
						}, slider.vars.animationSpeed, slider.vars.easing, slider.wrapup);
					} else {
						slider.slides.eq(slider.currentSlide).css({
							"opacity": 0,
							"zIndex": 1
						});
						slider.slides.eq(target).css({
							"opacity": 1,
							"zIndex": 2
						});
						slider.wrapup(dimension);
					}
				}
				if (slider.vars.smoothHeight) {
					methods.smoothHeight(slider.vars.animationSpeed);
				}
			}
		};
		slider.wrapup = function(dimension) {
			if (!fade && !carousel) {
				if (slider.currentSlide === 0 && slider.animatingTo === slider.last && slider.vars.animationLoop) {
					slider.setProps(dimension, "jumpEnd");
				} else if (slider.currentSlide === slider.last && slider.animatingTo === 0 && slider.vars.animationLoop) {
					slider.setProps(dimension, "jumpStart");
				}
			}
			slider.animating = false;
			slider.currentSlide = slider.animatingTo;
			slider.vars.after(slider);
		};
		slider.animateSlides = function() {
			if (!slider.animating && focused) {
				slider.flexAnimate(slider.getTarget("next"));
			}
		};
		slider.pause = function() {
			clearInterval(slider.animatedSlides);
			slider.animatedSlides = null;
			slider.playing = false;
			if (slider.vars.pausePlay) {
				methods.pausePlay.update("play");
			}
			if (slider.syncExists) {
				methods.sync("pause");
			}
		};
		slider.play = function() {
			if (slider.playing) {
				clearInterval(slider.animatedSlides);
			}
			slider.animatedSlides = slider.animatedSlides || setInterval(slider.animateSlides, slider.vars.slideshowSpeed);
			slider.started = slider.playing = true;
			if (slider.vars.pausePlay) {
				methods.pausePlay.update("pause");
			}
			if (slider.syncExists) {
				methods.sync("play");
			}
		};
		slider.stop = function() {
			slider.pause();
			slider.stopped = true;
		};
		slider.canAdvance = function(target, fromNav) {
			var last = (asNav) ? slider.pagingCount - 1 : slider.last;
			return (fromNav) ? true : (asNav && slider.currentItem === slider.count - 1 && target === 0 && slider.direction === "prev") ? true : (asNav && slider.currentItem === 0 && target === slider.pagingCount - 1 && slider.direction !== "next") ? false : (target === slider.currentSlide && !asNav) ? false : (slider.vars.animationLoop) ? true : (slider.atEnd && slider.currentSlide === 0 && target === last && slider.direction !== "next") ? false : (slider.atEnd && slider.currentSlide === last && target === 0 && slider.direction === "next") ? false : true;
		};
		slider.getTarget = function(dir) {
			slider.direction = dir;
			if (dir === "next") {
				return (slider.currentSlide === slider.last) ? 0 : slider.currentSlide + 1;
			} else {
				return (slider.currentSlide === 0) ? slider.last : slider.currentSlide - 1;
			}
		};
		slider.setProps = function(pos, special, dur) {
			var target = (function() {
				var posCheck = (pos) ? pos : ((slider.itemW + slider.vars.itemMargin) * slider.move) * slider.animatingTo,
					posCalc = (function() {
						if (carousel) {
							return (special === "setTouch") ? pos : (reverse && slider.animatingTo === slider.last) ? 0 : (reverse) ? slider.limit - (((slider.itemW + slider.vars.itemMargin) * slider.move) * slider.animatingTo) : (slider.animatingTo === slider.last) ? slider.limit : posCheck;
						} else {
							switch (special) {
							case "setTotal":
								return (reverse) ? ((slider.count - 1) - slider.currentSlide + slider.cloneOffset) * pos : (slider.currentSlide + slider.cloneOffset) * pos;
							case "setTouch":
								return (reverse) ? pos : pos;
							case "jumpEnd":
								return (reverse) ? pos : slider.count * pos;
							case "jumpStart":
								return (reverse) ? slider.count * pos : pos;
							default:
								return pos;
							}
						}
					}());
				return (posCalc * -1) + "px";
			}());
			if (slider.transitions) {
				target = (vertical) ? "translate3d(0," + target + ",0)" : "translate3d(" + target + ",0,0)";
				dur = (dur !== undefined) ? (dur / 1000) + "s" : "0s";
				slider.container.css("-" + slider.pfx + "-transition-duration", dur);
				slider.container.css("transition-duration", dur);
			}
			slider.args[slider.prop] = target;
			if (slider.transitions || dur === undefined) {
				slider.container.css(slider.args);
			}
			slider.container.css('transform', target);
		};
		slider.setup = function(type) {
			if (!fade) {
				var sliderOffset, arr;
				if (type === "init") {
					slider.viewport = $('<div class="' + namespace + 'viewport"></div>').css({
						"overflow": "hidden",
						"position": "relative"
					}).appendTo(slider).append(slider.container);
					slider.cloneCount = 0;
					slider.cloneOffset = 0;
					if (reverse) {
						arr = $.makeArray(slider.slides).reverse();
						slider.slides = $(arr);
						slider.container.empty().append(slider.slides);
					}
				}
				if (slider.vars.animationLoop && !carousel) {
					slider.cloneCount = 2;
					slider.cloneOffset = 1;
					if (type !== "init") {
						slider.container.find('.clone').remove();
					}
					slider.container.append(methods.uniqueID(slider.slides.first().clone().addClass('clone')).attr('aria-hidden', 'true')).prepend(methods.uniqueID(slider.slides.last().clone().addClass('clone')).attr('aria-hidden', 'true'));
				}
				slider.newSlides = $(slider.vars.selector, slider);
				sliderOffset = (reverse) ? slider.count - 1 - slider.currentSlide + slider.cloneOffset : slider.currentSlide + slider.cloneOffset;
				if (vertical && !carousel) {
					slider.container.height((slider.count + slider.cloneCount) * 200 + "%").css("position", "absolute").width("100%");
					setTimeout(function() {
						slider.newSlides.css({
							"display": "block"
						});
						slider.doMath();
						slider.viewport.height(slider.h);
						slider.setProps(sliderOffset * slider.h, "init");
					}, (type === "init") ? 100 : 0);
				} else {
					slider.container.width((slider.count + slider.cloneCount) * 200 + "%");
					slider.setProps(sliderOffset * slider.computedW, "init");
					setTimeout(function() {
						slider.doMath();
						slider.newSlides.css({
							"width": slider.computedW,
							"float": "left",
							"display": "block"
						});
						if (slider.vars.smoothHeight) {
							methods.smoothHeight();
						}
					}, (type === "init") ? 100 : 0);
				}
			} else {
				slider.slides.css({
					"width": "100%",
					"float": "left",
					"marginRight": "-100%",
					"position": "relative"
				});
				if (type === "init") {
					if (!touch) {
						if (slider.vars.fadeFirstSlide == false) {
							slider.slides.css({
								"opacity": 0,
								"display": "block",
								"zIndex": 1
							}).eq(slider.currentSlide).css({
								"zIndex": 2
							}).css({
								"opacity": 1
							});
						} else {
							slider.slides.css({
								"opacity": 0,
								"display": "block",
								"zIndex": 1
							}).eq(slider.currentSlide).css({
								"zIndex": 2
							}).animate({
								"opacity": 1
							}, slider.vars.animationSpeed, slider.vars.easing);
						}
					} else {
						slider.slides.css({
							"opacity": 0,
							"display": "block",
							"webkitTransition": "opacity " + slider.vars.animationSpeed / 1000 + "s ease",
							"zIndex": 1
						}).eq(slider.currentSlide).css({
							"opacity": 1,
							"zIndex": 2
						});
					}
				}
				if (slider.vars.smoothHeight) {
					methods.smoothHeight();
				}
			}
			if (!carousel) {
				slider.slides.removeClass(namespace + "active-slide").eq(slider.currentSlide).addClass(namespace + "active-slide");
			}
			slider.vars.init(slider);
		};
		slider.doMath = function() {
			var slide = slider.slides.first(),
				slideMargin = slider.vars.itemMargin,
				minItems = slider.vars.minItems,
				maxItems = slider.vars.maxItems;
			slider.w = (slider.viewport === undefined) ? slider.width() : slider.viewport.width();
			slider.h = slide.height();
			slider.boxPadding = slide.outerWidth() - slide.width();
			if (carousel) {
				slider.itemT = slider.vars.itemWidth + slideMargin;
				slider.minW = (minItems) ? minItems * slider.itemT : slider.w;
				slider.maxW = (maxItems) ? (maxItems * slider.itemT) - slideMargin : slider.w;
				slider.itemW = (slider.minW > slider.w) ? (slider.w - (slideMargin * (minItems - 1))) / minItems : (slider.maxW < slider.w) ? (slider.w - (slideMargin * (maxItems - 1))) / maxItems : (slider.vars.itemWidth > slider.w) ? slider.w : slider.vars.itemWidth;
				slider.visible = Math.floor(slider.w / (slider.itemW));
				slider.move = (slider.vars.move > 0 && slider.vars.move < slider.visible) ? slider.vars.move : slider.visible;
				slider.pagingCount = Math.ceil(((slider.count - slider.visible) / slider.move) + 1);
				slider.last = slider.pagingCount - 1;
				slider.limit = (slider.pagingCount === 1) ? 0 : (slider.vars.itemWidth > slider.w) ? (slider.itemW * (slider.count - 1)) + (slideMargin * (slider.count - 1)) : ((slider.itemW + slideMargin) * slider.count) - slider.w - slideMargin;
			} else {
				slider.itemW = slider.w;
				slider.pagingCount = slider.count;
				slider.last = slider.count - 1;
			}
			slider.computedW = slider.itemW - slider.boxPadding;
		};
		slider.update = function(pos, action) {
			slider.doMath();
			if (!carousel) {
				if (pos < slider.currentSlide) {
					slider.currentSlide += 1;
				} else if (pos <= slider.currentSlide && pos !== 0) {
					slider.currentSlide -= 1;
				}
				slider.animatingTo = slider.currentSlide;
			}
			if (slider.vars.controlNav && !slider.manualControls) {
				if ((action === "add" && !carousel) || slider.pagingCount > slider.controlNav.length) {
					methods.controlNav.update("add");
				} else if ((action === "remove" && !carousel) || slider.pagingCount < slider.controlNav.length) {
					if (carousel && slider.currentSlide > slider.last) {
						slider.currentSlide -= 1;
						slider.animatingTo -= 1;
					}
					methods.controlNav.update("remove", slider.last);
				}
			}
			if (slider.vars.directionNav) {
				methods.directionNav.update();
			}
		};
		slider.addSlide = function(obj, pos) {
			var $obj = $(obj);
			slider.count += 1;
			slider.last = slider.count - 1;
			if (vertical && reverse) {
				(pos !== undefined) ? slider.slides.eq(slider.count - pos).after($obj) : slider.container.prepend($obj);
			} else {
				(pos !== undefined) ? slider.slides.eq(pos).before($obj) : slider.container.append($obj);
			}
			slider.update(pos, "add");
			slider.slides = $(slider.vars.selector + ':not(.clone)', slider);
			slider.setup();
			slider.vars.added(slider);
		};
		slider.removeSlide = function(obj) {
			var pos = (isNaN(obj)) ? slider.slides.index($(obj)) : obj;
			slider.count -= 1;
			slider.last = slider.count - 1;
			if (isNaN(obj)) {
				$(obj, slider.slides).remove();
			} else {
				(vertical && reverse) ? slider.slides.eq(slider.last).remove() : slider.slides.eq(obj).remove();
			}
			slider.doMath();
			slider.update(pos, "remove");
			slider.slides = $(slider.vars.selector + ':not(.clone)', slider);
			slider.setup();
			slider.vars.removed(slider);
		};
		methods.init();
	};
	$(window).blur(function(e) {
		focused = false;
	}).focus(function(e) {
		focused = true;
	});
	$.flexslider.defaults = {
		namespace: "flex-",
		selector: ".slides > li",
		animation: "fade",
		easing: "swing",
		direction: "horizontal",
		reverse: false,
		animationLoop: true,
		smoothHeight: false,
		startAt: 0,
		slideshow: true,
		slideshowSpeed: 7000,
		animationSpeed: 600,
		initDelay: 0,
		randomize: false,
		fadeFirstSlide: true,
		thumbCaptions: false,
		pauseOnAction: true,
		pauseOnHover: false,
		pauseInvisible: true,
		useCSS: true,
		touch: true,
		video: false,
		controlNav: true,
		directionNav: true,
		prevText: "Previous",
		nextText: "Next",
		keyboard: true,
		multipleKeyboard: false,
		mousewheel: false,
		pausePlay: false,
		pauseText: "Pause",
		playText: "Play",
		controlsContainer: "",
		manualControls: "",
		customDirectionNav: "",
		sync: "",
		asNavFor: "",
		itemWidth: 0,
		itemMargin: 0,
		minItems: 1,
		maxItems: 0,
		move: 0,
		allowOneSlide: true,
		start: function() {},
		before: function() {},
		after: function() {},
		end: function() {},
		added: function() {},
		removed: function() {},
		init: function() {}
	};
	$.fn.flexslider = function(options) {
		if (options === undefined) {
			options = {};
		}
		if (typeof options === "object") {
			return this.each(function() {
				var $this = $(this),
					selector = (options.selector) ? options.selector : ".slides > li",
					$slides = $this.find(selector);
				if (($slides.length === 1 && options.allowOneSlide === true) || $slides.length === 0) {
					$slides.fadeIn(400);
					if (options.start) {
						options.start($this);
					}
				} else if ($this.data('flexslider') === undefined) {
					new $.flexslider(this, options);
				}
			});
		} else {
			var $slider = $(this).data('flexslider');
			switch (options) {
			case "play":
				$slider.play();
				break;
			case "pause":
				$slider.pause();
				break;
			case "stop":
				$slider.stop();
				break;
			case "next":
				$slider.flexAnimate($slider.getTarget("next"), true);
				break;
			case "prev":
			case "previous":
				$slider.flexAnimate($slider.getTarget("prev"), true);
				break;
			default:
				if (typeof options === "number") {
					$slider.flexAnimate(options, true);
				}
			}
		}
	};
})(jQuery);
(function($) {
	$.isScrollToFixed = function(el) {
		return !!$(el).data('ScrollToFixed');
	};
	$.ScrollToFixed = function(el, options) {
		var base = this;
		base.$el = $(el);
		base.el = el;
		base.$el.data('ScrollToFixed', base);
		var isReset = false;
		var target = base.$el;
		var position;
		var originalPosition;
		var originalFloat;
		var originalOffsetTop;
		var originalZIndex;
		var offsetTop = 0;
		var offsetLeft = 0;
		var originalOffsetLeft = -1;
		var lastOffsetLeft = -1;
		var spacer = null;
		var spacerClass;
		var className;

		function resetScroll() {
			target.trigger('preUnfixed.ScrollToFixed');
			setUnfixed();
			target.trigger('unfixed.ScrollToFixed');
			lastOffsetLeft = -1;
			offsetTop = target.offset().top;
			offsetLeft = target.offset().left;
			if (base.options.offsets) {
				offsetLeft += (target.offset().left - target.position().left);
			}
			if (originalOffsetLeft == -1) {
				originalOffsetLeft = offsetLeft;
			}
			position = target.css('position');
			isReset = true;
			if (base.options.bottom != -1) {
				target.trigger('preFixed.ScrollToFixed');
				setFixed();
				target.trigger('fixed.ScrollToFixed');
			}
		}
		function getLimit() {
			var limit = base.options.limit;
			if (!limit) return 0;
			if (typeof(limit) === 'function') {
				return limit.apply(target);
			}
			return limit;
		}
		function isFixed() {
			return position === 'fixed';
		}
		function isAbsolute() {
			return position === 'absolute';
		}
		function isUnfixed() {
			return !(isFixed() || isAbsolute());
		}
		function setFixed() {
			if (!isFixed()) {
				var dimensions = target[0].getBoundingClientRect();
				spacer.css({
					'display': target.css('display'),
					'width': dimensions.width,
					'height': dimensions.height,
					'float': target.css('float')
				});
				cssOptions = {
					'z-index': base.options.zIndex,
					'position': 'fixed',
					'top': base.options.bottom == -1 ? getMarginTop() : '',
					'bottom': base.options.bottom == -1 ? '' : base.options.bottom,
					'margin-left': '0px'
				}
				if (!base.options.dontSetWidth) {
					cssOptions['width'] = target.css('width');
				};
				target.css(cssOptions);
				target.addClass(base.options.baseClassName);
				if (base.options.className) {
					target.addClass(base.options.className);
				}
				position = 'fixed';
			}
		}
		function setAbsolute() {
			var top = getLimit();
			var left = offsetLeft;
			if (base.options.removeOffsets) {
				left = '';
				top = top - offsetTop;
			}
			cssOptions = {
				'position': 'absolute',
				'top': top,
				'left': left,
				'margin-left': '0px',
				'bottom': ''
			}
			if (!base.options.dontSetWidth) {
				cssOptions['width'] = target.css('width');
			};
			target.css(cssOptions);
			position = 'absolute';
		}
		function setUnfixed() {
			if (!isUnfixed()) {
				lastOffsetLeft = -1;
				spacer.css('display', 'none');
				target.css({
					'z-index': originalZIndex,
					'width': '',
					'position': originalPosition,
					'left': '',
					'top': originalOffsetTop,
					'margin-left': ''
				});
				target.removeClass('scroll-to-fixed-fixed');
				if (base.options.className) {
					target.removeClass(base.options.className);
				}
				position = null;
			}
		}
		function setLeft(x) {
			if (x != lastOffsetLeft) {
				target.css('left', offsetLeft - x);
				lastOffsetLeft = x;
			}
		}
		function getMarginTop() {
			var marginTop = base.options.marginTop;
			if (!marginTop) return 0;
			if (typeof(marginTop) === 'function') {
				return marginTop.apply(target);
			}
			return marginTop;
		}
		function checkScroll() {
			if (!$.isScrollToFixed(target) || target.is(':hidden')) return;
			var wasReset = isReset;
			var wasUnfixed = isUnfixed();
			if (!isReset) {
				resetScroll();
			} else if (isUnfixed()) {
				offsetTop = target.offset().top;
				offsetLeft = target.offset().left;
			}
			var x = $(window).scrollLeft();
			var y = $(window).scrollTop();
			var limit = getLimit();
			if (base.options.minWidth && $(window).width() < base.options.minWidth) {
				if (!isUnfixed() || !wasReset) {
					postPosition();
					target.trigger('preUnfixed.ScrollToFixed');
					setUnfixed();
					target.trigger('unfixed.ScrollToFixed');
				}
			} else if (base.options.maxWidth && $(window).width() > base.options.maxWidth) {
				if (!isUnfixed() || !wasReset) {
					postPosition();
					target.trigger('preUnfixed.ScrollToFixed');
					setUnfixed();
					target.trigger('unfixed.ScrollToFixed');
				}
			} else if (base.options.bottom == -1) {
				if (limit > 0 && y >= limit - getMarginTop()) {
					if (!wasUnfixed && (!isAbsolute() || !wasReset)) {
						postPosition();
						target.trigger('preAbsolute.ScrollToFixed');
						setAbsolute();
						target.trigger('unfixed.ScrollToFixed');
					}
				} else if (y >= offsetTop - getMarginTop()) {
					if (!isFixed() || !wasReset) {
						postPosition();
						target.trigger('preFixed.ScrollToFixed');
						setFixed();
						lastOffsetLeft = -1;
						target.trigger('fixed.ScrollToFixed');
					}
					setLeft(x);
				} else {
					if (!isUnfixed() || !wasReset) {
						postPosition();
						target.trigger('preUnfixed.ScrollToFixed');
						setUnfixed();
						target.trigger('unfixed.ScrollToFixed');
					}
				}
			} else {
				if (limit > 0) {
					if (y + $(window).height() - target.outerHeight(true) >= limit - (getMarginTop() || -getBottom())) {
						if (isFixed()) {
							postPosition();
							target.trigger('preUnfixed.ScrollToFixed');
							if (originalPosition === 'absolute') {
								setAbsolute();
							} else {
								setUnfixed();
							}
							target.trigger('unfixed.ScrollToFixed');
						}
					} else {
						if (!isFixed()) {
							postPosition();
							target.trigger('preFixed.ScrollToFixed');
							setFixed();
						}
						setLeft(x);
						target.trigger('fixed.ScrollToFixed');
					}
				} else {
					setLeft(x);
				}
			}
		}
		function getBottom() {
			if (!base.options.bottom) return 0;
			return base.options.bottom;
		}
		function postPosition() {
			var position = target.css('position');
			if (position == 'absolute') {
				target.trigger('postAbsolute.ScrollToFixed');
			} else if (position == 'fixed') {
				target.trigger('postFixed.ScrollToFixed');
			} else {
				target.trigger('postUnfixed.ScrollToFixed');
			}
		}
		var windowResize = function(event) {
				if (target.is(':visible')) {
					isReset = false;
					checkScroll();
				} else {
					setUnfixed();
				}
			}
		var windowScroll = function(event) {
				( !! window.requestAnimationFrame) ? requestAnimationFrame(checkScroll) : checkScroll();
			}
		var isPositionFixedSupported = function() {
				var container = document.body;
				if (document.createElement && container && container.appendChild && container.removeChild) {
					var el = document.createElement('div');
					if (!el.getBoundingClientRect) return null;
					el.innerHTML = 'x';
					el.style.cssText = 'position:fixed;top:100px;';
					container.appendChild(el);
					var originalHeight = container.style.height,
						originalScrollTop = container.scrollTop;
					container.style.height = '3000px';
					container.scrollTop = 500;
					var elementTop = el.getBoundingClientRect().top;
					container.style.height = originalHeight;
					var isSupported = (elementTop === 100);
					container.removeChild(el);
					container.scrollTop = originalScrollTop;
					return isSupported;
				}
				return null;
			}
		var preventDefault = function(e) {
				e = e || window.event;
				if (e.preventDefault) {
					e.preventDefault();
				}
				e.returnValue = false;
			}
		base.init = function() {
			base.options = $.extend({}, $.ScrollToFixed.defaultOptions, options);
			originalZIndex = target.css('z-index')
			base.$el.css('z-index', base.options.zIndex);
			spacer = $('<div />');
			position = target.css('position');
			originalPosition = target.css('position');
			originalFloat = target.css('float');
			originalOffsetTop = target.css('top');
			if (isUnfixed()) base.$el.after(spacer);
			$(window).bind('resize.ScrollToFixed', windowResize);
			$(window).bind('scroll.ScrollToFixed', windowScroll);
			if ('ontouchmove' in window) {
				$(window).bind('touchmove.ScrollToFixed', checkScroll);
			}
			if (base.options.preFixed) {
				target.bind('preFixed.ScrollToFixed', base.options.preFixed);
			}
			if (base.options.postFixed) {
				target.bind('postFixed.ScrollToFixed', base.options.postFixed);
			}
			if (base.options.preUnfixed) {
				target.bind('preUnfixed.ScrollToFixed', base.options.preUnfixed);
			}
			if (base.options.postUnfixed) {
				target.bind('postUnfixed.ScrollToFixed', base.options.postUnfixed);
			}
			if (base.options.preAbsolute) {
				target.bind('preAbsolute.ScrollToFixed', base.options.preAbsolute);
			}
			if (base.options.postAbsolute) {
				target.bind('postAbsolute.ScrollToFixed', base.options.postAbsolute);
			}
			if (base.options.fixed) {
				target.bind('fixed.ScrollToFixed', base.options.fixed);
			}
			if (base.options.unfixed) {
				target.bind('unfixed.ScrollToFixed', base.options.unfixed);
			}
			if (base.options.spacerClass) {
				spacer.addClass(base.options.spacerClass);
			}
			target.bind('resize.ScrollToFixed', function() {
				spacer.height(target.height());
			});
			target.bind('scroll.ScrollToFixed', function() {
				target.trigger('preUnfixed.ScrollToFixed');
				setUnfixed();
				target.trigger('unfixed.ScrollToFixed');
				checkScroll();
			});
			target.bind('detach.ScrollToFixed', function(ev) {
				preventDefault(ev);
				target.trigger('preUnfixed.ScrollToFixed');
				setUnfixed();
				target.trigger('unfixed.ScrollToFixed');
				$(window).unbind('resize.ScrollToFixed', windowResize);
				$(window).unbind('scroll.ScrollToFixed', windowScroll);
				target.unbind('.ScrollToFixed');
				spacer.remove();
				base.$el.removeData('ScrollToFixed');
			});
			windowResize();
		};
		base.init();
	};
	$.ScrollToFixed.defaultOptions = {
		marginTop: 0,
		limit: 0,
		bottom: -1,
		zIndex: 1000,
		baseClassName: 'scroll-to-fixed-fixed'
	};
	$.fn.scrollToFixed = function(options) {
		return this.each(function() {
			(new $.ScrollToFixed(this, options));
		});
	};
})(jQuery);
(function(root, factory) {
	if (typeof define === 'function' && define.amd) {
		define(['jquery'], factory);
	} else if (typeof exports === 'object') {
		module.exports = factory(require('jquery'));
	} else {
		root.lightbox = factory(root.jQuery);
	}
}(this, function($) {
	function Lightbox(options) {
		this.album = [];
		this.currentImageIndex = void 0;
		this.init();
		this.options = $.extend({}, this.constructor.defaults);
		this.option(options);
	}
	Lightbox.defaults = {
		albumLabel: 'Image %1 of %2',
		alwaysShowNavOnTouchDevices: false,
		fadeDuration: 500,
		fitImagesInViewport: true,
		positionFromTop: 50,
		resizeDuration: 700,
		showImageNumberLabel: true,
		wrapAround: false
	};
	Lightbox.prototype.option = function(options) {
		$.extend(this.options, options);
	};
	Lightbox.prototype.imageCountLabel = function(currentImageNum, totalImages) {
		return this.options.albumLabel.replace(/%1/g, currentImageNum).replace(/%2/g, totalImages);
	};
	Lightbox.prototype.init = function() {
		this.enable();
		this.build();
	};
	Lightbox.prototype.enable = function() {
		var self = this;
		$('body').on('click', 'a[rel^=lightbox], area[rel^=lightbox], a[data-lightbox], area[data-lightbox]', function(event) {
			self.start($(event.currentTarget));
			return false;
		});
	};
	Lightbox.prototype.build = function() {
		var self = this;
		$('<div id="lightboxOverlay" class="lightboxOverlay"></div><div id="lightbox" class="lightbox"><div class="lb-outerContainer"><div class="lb-container"><img class="lb-image" src="data:image/gif;base64,R0lGODlhAQABAIAAAP///wAAACH5BAEAAAAALAAAAAABAAEAAAICRAEAOw==" /><div class="lb-nav"><a class="lb-prev" href="" ></a><a class="lb-next" href="" ></a></div><div class="lb-loader"><a class="lb-cancel"></a></div></div></div><div class="lb-dataContainer"><div class="lb-data"><div class="lb-details"><span class="lb-caption"></span><span class="lb-number"></span></div><div class="lb-closeContainer"><a class="lb-close"></a></div></div></div></div>').appendTo($('body'));
		this.$lightbox = $('#lightbox');
		this.$overlay = $('#lightboxOverlay');
		this.$outerContainer = this.$lightbox.find('.lb-outerContainer');
		this.$container = this.$lightbox.find('.lb-container');
		this.containerTopPadding = parseInt(this.$container.css('padding-top'), 10);
		this.containerRightPadding = parseInt(this.$container.css('padding-right'), 10);
		this.containerBottomPadding = parseInt(this.$container.css('padding-bottom'), 10);
		this.containerLeftPadding = parseInt(this.$container.css('padding-left'), 10);
		this.$overlay.hide().on('click', function() {
			self.end();
			return false;
		});
		this.$lightbox.hide().on('click', function(event) {
			if ($(event.target).attr('id') === 'lightbox') {
				self.end();
			}
			return false;
		});
		this.$outerContainer.on('click', function(event) {
			if ($(event.target).attr('id') === 'lightbox') {
				self.end();
			}
			return false;
		});
		this.$lightbox.find('.lb-prev').on('click', function() {
			if (self.currentImageIndex === 0) {
				self.changeImage(self.album.length - 1);
			} else {
				self.changeImage(self.currentImageIndex - 1);
			}
			return false;
		});
		this.$lightbox.find('.lb-next').on('click', function() {
			if (self.currentImageIndex === self.album.length - 1) {
				self.changeImage(0);
			} else {
				self.changeImage(self.currentImageIndex + 1);
			}
			return false;
		});
		this.$lightbox.find('.lb-loader, .lb-close').on('click', function() {
			self.end();
			return false;
		});
	};
	Lightbox.prototype.start = function($link) {
		var self = this;
		var $window = $(window);
		$window.on('resize', $.proxy(this.sizeOverlay, this));
		$('select, object, embed').css({
			visibility: 'hidden'
		});
		this.sizeOverlay();
		this.album = [];
		var imageNumber = 0;

		function addToAlbum($link) {
			self.album.push({
				link: $link.attr('href'),
				title: $link.attr('data-title') || $link.attr('title')
			});
		}
		var dataLightboxValue = $link.attr('data-lightbox');
		var $links;
		if (dataLightboxValue) {
			$links = $($link.prop('tagName') + '[data-lightbox="' + dataLightboxValue + '"]');
			for (var i = 0; i < $links.length; i = ++i) {
				addToAlbum($($links[i]));
				if ($links[i] === $link[0]) {
					imageNumber = i;
				}
			}
		} else {
			if ($link.attr('rel') === 'lightbox') {
				addToAlbum($link);
			} else {
				$links = $($link.prop('tagName') + '[rel="' + $link.attr('rel') + '"]');
				for (var j = 0; j < $links.length; j = ++j) {
					addToAlbum($($links[j]));
					if ($links[j] === $link[0]) {
						imageNumber = j;
					}
				}
			}
		}
		var top = $window.scrollTop() + this.options.positionFromTop;
		var left = $window.scrollLeft();
		this.$lightbox.css({
			top: top + 'px',
			left: left + 'px'
		}).fadeIn(this.options.fadeDuration);
		this.changeImage(imageNumber);
	};
	Lightbox.prototype.changeImage = function(imageNumber) {
		var self = this;
		this.disableKeyboardNav();
		var $image = this.$lightbox.find('.lb-image');
		this.$overlay.fadeIn(this.options.fadeDuration);
		$('.lb-loader').fadeIn('slow');
		this.$lightbox.find('.lb-image, .lb-nav, .lb-prev, .lb-next, .lb-dataContainer, .lb-numbers, .lb-caption').hide();
		this.$outerContainer.addClass('animating');
		var preloader = new Image();
		preloader.onload = function() {
			var $preloader;
			var imageHeight;
			var imageWidth;
			var maxImageHeight;
			var maxImageWidth;
			var windowHeight;
			var windowWidth;
			$image.attr('src', self.album[imageNumber].link);
			$preloader = $(preloader);
			$image.width(preloader.width);
			$image.height(preloader.height);
			if (self.options.fitImagesInViewport) {
				windowWidth = $(window).width();
				windowHeight = $(window).height();
				maxImageWidth = windowWidth - self.containerLeftPadding - self.containerRightPadding - 20;
				maxImageHeight = windowHeight - self.containerTopPadding - self.containerBottomPadding - 120;
				if (self.options.maxWidth && self.options.maxWidth < maxImageWidth) {
					maxImageWidth = self.options.maxWidth;
				}
				if (self.options.maxHeight && self.options.maxHeight < maxImageWidth) {
					maxImageHeight = self.options.maxHeight;
				}
				if ((preloader.width > maxImageWidth) || (preloader.height > maxImageHeight)) {
					if ((preloader.width / maxImageWidth) > (preloader.height / maxImageHeight)) {
						imageWidth = maxImageWidth;
						imageHeight = parseInt(preloader.height / (preloader.width / imageWidth), 10);
						$image.width(imageWidth);
						$image.height(imageHeight);
					} else {
						imageHeight = maxImageHeight;
						imageWidth = parseInt(preloader.width / (preloader.height / imageHeight), 10);
						$image.width(imageWidth);
						$image.height(imageHeight);
					}
				}
			}
			self.sizeContainer($image.width(), $image.height());
		};
		preloader.src = this.album[imageNumber].link;
		this.currentImageIndex = imageNumber;
	};
	Lightbox.prototype.sizeOverlay = function() {
		this.$overlay.width($(window).width()).height($(document).height());
	};
	Lightbox.prototype.sizeContainer = function(imageWidth, imageHeight) {
		var self = this;
		var oldWidth = this.$outerContainer.outerWidth();
		var oldHeight = this.$outerContainer.outerHeight();
		var newWidth = imageWidth + this.containerLeftPadding + this.containerRightPadding;
		var newHeight = imageHeight + this.containerTopPadding + this.containerBottomPadding;

		function postResize() {
			self.$lightbox.find('.lb-dataContainer').width(newWidth);
			self.$lightbox.find('.lb-prevLink').height(newHeight);
			self.$lightbox.find('.lb-nextLink').height(newHeight);
			self.showImage();
		}
		if (oldWidth !== newWidth || oldHeight !== newHeight) {
			this.$outerContainer.animate({
				width: newWidth,
				height: newHeight
			}, this.options.resizeDuration, 'swing', function() {
				postResize();
			});
		} else {
			postResize();
		}
	};
	Lightbox.prototype.showImage = function() {
		this.$lightbox.find('.lb-loader').stop(true).hide();
		this.$lightbox.find('.lb-image').fadeIn('slow');
		this.updateNav();
		this.updateDetails();
		this.preloadNeighboringImages();
		this.enableKeyboardNav();
	};
	Lightbox.prototype.updateNav = function() {
		var alwaysShowNav = false;
		try {
			document.createEvent('TouchEvent');
			alwaysShowNav = (this.options.alwaysShowNavOnTouchDevices) ? true : false;
		} catch (e) {}
		this.$lightbox.find('.lb-nav').show();
		if (this.album.length > 1) {
			if (this.options.wrapAround) {
				if (alwaysShowNav) {
					this.$lightbox.find('.lb-prev, .lb-next').css('opacity', '1');
				}
				this.$lightbox.find('.lb-prev, .lb-next').show();
			} else {
				if (this.currentImageIndex > 0) {
					this.$lightbox.find('.lb-prev').show();
					if (alwaysShowNav) {
						this.$lightbox.find('.lb-prev').css('opacity', '1');
					}
				}
				if (this.currentImageIndex < this.album.length - 1) {
					this.$lightbox.find('.lb-next').show();
					if (alwaysShowNav) {
						this.$lightbox.find('.lb-next').css('opacity', '1');
					}
				}
			}
		}
	};
	Lightbox.prototype.updateDetails = function() {
		var self = this;
		if (typeof this.album[this.currentImageIndex].title !== 'undefined' && this.album[this.currentImageIndex].title !== '') {
			this.$lightbox.find('.lb-caption').html(this.album[this.currentImageIndex].title).fadeIn('fast').find('a').on('click', function(event) {
				if ($(this).attr('target') !== undefined) {
					window.open($(this).attr('href'), $(this).attr('target'));
				} else {
					location.href = $(this).attr('href');
				}
			});
		}
		if (this.album.length > 1 && this.options.showImageNumberLabel) {
			var labelText = this.imageCountLabel(this.currentImageIndex + 1, this.album.length);
			this.$lightbox.find('.lb-number').text(labelText).fadeIn('fast');
		} else {
			this.$lightbox.find('.lb-number').hide();
		}
		this.$outerContainer.removeClass('animating');
		this.$lightbox.find('.lb-dataContainer').fadeIn(this.options.resizeDuration, function() {
			return self.sizeOverlay();
		});
	};
	Lightbox.prototype.preloadNeighboringImages = function() {
		if (this.album.length > this.currentImageIndex + 1) {
			var preloadNext = new Image();
			preloadNext.src = this.album[this.currentImageIndex + 1].link;
		}
		if (this.currentImageIndex > 0) {
			var preloadPrev = new Image();
			preloadPrev.src = this.album[this.currentImageIndex - 1].link;
		}
	};
	Lightbox.prototype.enableKeyboardNav = function() {
		$(document).on('keyup.keyboard', $.proxy(this.keyboardAction, this));
	};
	Lightbox.prototype.disableKeyboardNav = function() {
		$(document).off('.keyboard');
	};
	Lightbox.prototype.keyboardAction = function(event) {
		var KEYCODE_ESC = 27;
		var KEYCODE_LEFTARROW = 37;
		var KEYCODE_RIGHTARROW = 39;
		var keycode = event.keyCode;
		var key = String.fromCharCode(keycode).toLowerCase();
		if (keycode === KEYCODE_ESC || key.match(/x|o|c/)) {
			this.end();
		} else if (key === 'p' || keycode === KEYCODE_LEFTARROW) {
			if (this.currentImageIndex !== 0) {
				this.changeImage(this.currentImageIndex - 1);
			} else if (this.options.wrapAround && this.album.length > 1) {
				this.changeImage(this.album.length - 1);
			}
		} else if (key === 'n' || keycode === KEYCODE_RIGHTARROW) {
			if (this.currentImageIndex !== this.album.length - 1) {
				this.changeImage(this.currentImageIndex + 1);
			} else if (this.options.wrapAround && this.album.length > 1) {
				this.changeImage(0);
			}
		}
	};
	Lightbox.prototype.end = function() {
		this.disableKeyboardNav();
		$(window).off('resize', this.sizeOverlay);
		this.$lightbox.fadeOut(this.options.fadeDuration);
		this.$overlay.fadeOut(this.options.fadeDuration);
		$('select, object, embed').css({
			visibility: 'visible'
		});
	};
	return new Lightbox();
}));
!
function(a, b, c, d) {
	var e = a(b);
	a.fn.lazyload = function(f) {
		function g() {
			var b = 0;
			i.each(function() {
				var c = a(this);
				if (!j.skip_invisible || c.is(":visible")) if (a.abovethetop(this, j) || a.leftofbegin(this, j));
				else if (a.belowthefold(this, j) || a.rightoffold(this, j)) {
					if (++b > j.failure_limit) return !1
				} else c.trigger("appear"), b = 0
			})
		}
		var h, i = this,
			j = {
				threshold: 0,
				failure_limit: 0,
				event: "scroll",
				effect: "show",
				container: b,
				data_attribute: "original",
				skip_invisible: !0,
				appear: null,
				load: null,
				placeholder: "data:image/png;base64,iVBORw0KGgoAAAANSUhEUgAAAAEAAAABCAYAAAAfFcSJAAAAAXNSR0IArs4c6QAAAARnQU1BAACxjwv8YQUAAAAJcEhZcwAADsQAAA7EAZUrDhsAAAANSURBVBhXYzh8+PB/AAffA0nNPuCLAAAAAElFTkSuQmCC"
			};
		return f && (d !== f.failurelimit && (f.failure_limit = f.failurelimit, delete f.failurelimit), d !== f.effectspeed && (f.effect_speed = f.effectspeed, delete f.effectspeed), a.extend(j, f)), h = j.container === d || j.container === b ? e : a(j.container), 0 === j.event.indexOf("scroll") && h.bind(j.event, function() {
			return g()
		}), this.each(function() {
			var b = this,
				c = a(b);
			b.loaded = !1, (c.attr("src") === d || c.attr("src") === !1) && c.is("img") && c.attr("src", j.placeholder), c.one("appear", function() {
				if (!this.loaded) {
					if (j.appear) {
						var d = i.length;
						j.appear.call(b, d, j)
					}
					a("<img />").bind("load", function() {
						var d = c.attr("data-" + j.data_attribute);
						c.hide(), c.is("img") ? c.attr("src", d) : c.css("background-image", "url('" + d + "')"), c[j.effect](j.effect_speed), b.loaded = !0;
						var e = a.grep(i, function(a) {
							return !a.loaded
						});
						if (i = a(e), j.load) {
							var f = i.length;
							j.load.call(b, f, j)
						}
					}).attr("src", c.attr("data-" + j.data_attribute))
				}
			}), 0 !== j.event.indexOf("scroll") && c.bind(j.event, function() {
				b.loaded || c.trigger("appear")
			})
		}), e.bind("resize", function() {
			g()
		}), /(?:iphone|ipod|ipad).*os 5/gi.test(navigator.appVersion) && e.bind("pageshow", function(b) {
			b.originalEvent && b.originalEvent.persisted && i.each(function() {
				a(this).trigger("appear")
			})
		}), a(c).ready(function() {
			g()
		}), this
	}, a.belowthefold = function(c, f) {
		var g;
		return g = f.container === d || f.container === b ? (b.innerHeight ? b.innerHeight : e.height()) + e.scrollTop() : a(f.container).offset().top + a(f.container).height(), g <= a(c).offset().top - f.threshold
	}, a.rightoffold = function(c, f) {
		var g;
		return g = f.container === d || f.container === b ? e.width() + e.scrollLeft() : a(f.container).offset().left + a(f.container).width(), g <= a(c).offset().left - f.threshold
	}, a.abovethetop = function(c, f) {
		var g;
		return g = f.container === d || f.container === b ? e.scrollTop() : a(f.container).offset().top, g >= a(c).offset().top + f.threshold + a(c).height()
	}, a.leftofbegin = function(c, f) {
		var g;
		return g = f.container === d || f.container === b ? e.scrollLeft() : a(f.container).offset().left, g >= a(c).offset().left + f.threshold + a(c).width()
	}, a.inviewport = function(b, c) {
		return !(a.rightoffold(b, c) || a.leftofbegin(b, c) || a.belowthefold(b, c) || a.abovethetop(b, c))
	}, a.extend(a.expr[":"], {
		"below-the-fold": function(b) {
			return a.belowthefold(b, {
				threshold: 0
			})
		},
		"above-the-top": function(b) {
			return !a.belowthefold(b, {
				threshold: 0
			})
		},
		"right-of-screen": function(b) {
			return a.rightoffold(b, {
				threshold: 0
			})
		},
		"left-of-screen": function(b) {
			return !a.rightoffold(b, {
				threshold: 0
			})
		},
		"in-viewport": function(b) {
			return a.inviewport(b, {
				threshold: 0
			})
		},
		"above-the-fold": function(b) {
			return !a.belowthefold(b, {
				threshold: 0
			})
		},
		"right-of-fold": function(b) {
			return a.rightoffold(b, {
				threshold: 0
			})
		},
		"left-of-fold": function(b) {
			return !a.rightoffold(b, {
				threshold: 0
			})
		}
	})
}(jQuery, window, document);
(function(e) {
	if (typeof define === "function" && define.amd) {
		define(["jquery"], e)
	} else if (typeof exports === "object") {
		e(require("jquery"))
	} else {
		e(jQuery)
	}
})(function(e) {
	e.extend({
		fblogin: function(t) {
			var n, r, i, s;
			t = t || {};
			r = false;
			i = false;
			s = e.Deferred();
			n = {
				init: function() {
					if (!t.fbId) {
						throw new Error('Required option "fbId" is missing!')
					}
					if (t.isFbInitiated) {
						i = t.isFbInitiated
					}
					t.permissions = t.permissions || "";
					t.fields = t.fields || "";
					t.success = t.success ||
					function() {};
					t.error = t.error ||
					function() {};
					n.listenForFbAsync()
				},
				listenForFbAsync: function() {
					if (window.fbAsyncInit) {
						var e = window.fbAsyncInit
					}
					window.fbAsyncInit = function() {
						n.initFB();
						r = true;
						if (e) {
							e()
						}
					};
					if (r || window.FB) {
						window.fbAsyncInit();
						return
					}
				},
				initFB: function() {
					if (!i && !window.isFbInitiated) {
						window.FB.init({
							appId: t.fbId,
							cookie: true,
							xfbml: true,
							version: "v2.0"
						});
						window.isFbInitiated = true;
						i = true
					}
					s.notify({
						status: "init.fblogin"
					})
				},
				loginToFB: function() {
					window.FB.login(function(e) {
						if (e.authResponse) {
							s.notify({
								status: "authenticate.fblogin",
								data: e
							})
						} else {
							s.reject({
								error: {
									message: "User cancelled login or did not fully authorize."
								}
							})
						}
					}, {
						scope: t.permissions,
						return_scopes: true
					})
				},
				getFbFields: function(e) {
					FB.api("/me", {
						fields: t.fields
					}, function(e) {
						if (e && !e.error) {
							s.resolve(e)
						} else {
							s.reject(e)
						}
					})
				}
			};
			s.progress(function(e) {
				if (e.status === "init.fblogin") {
					n.loginToFB()
				} else if (e.status === "authenticate.fblogin") {
					n.getFbFields(e.data.authResponse.accessToken)
				} else {
					dfd.reject()
				}
			});
			s.done(t.success);
			s.fail(t.error);
			n.init();
			return s
		}
	})
})